@@ -134,8 +134,7 @@ setReplaceMethod("rname", "GAlignments",
 setReplaceMethod("strand", "GAlignments",
     function(x, value) 
     {
-        x@strand <-
-            GenomicRanges:::normargGenomicRangesStrand(value, length(x))
+        x@strand <- GenomicRanges:::normalize_strand_replacement_value(value, x)
         x
     }
 )
@@ -145,7 +144,7 @@ setReplaceMethod("strand", "GAlignments",
 ### FIXME: This repeats most of the code in
 ###        GenomicRanges:::set_GenomicRanges_seqinfo!
 set_GAlignments_seqinfo <-
-    function(x, new2old=NULL, force=FALSE,
+    function(x, new2old=NULL,
              pruning.mode=c("error", "coarse", "fine", "tidy"),
              value)
 {
@@ -156,7 +155,7 @@ set_GAlignments_seqinfo <-
     if (!is(value, "Seqinfo"))
         stop("the supplied 'seqinfo' must be a Seqinfo object")
     dangling_seqlevels <- GenomeInfoDb:::getDanglingSeqlevels(x,
-                              new2old=new2old, force=force,
+                              new2old=new2old,
                               pruning.mode=pruning.mode,
                               seqlevels(value))
     if (length(dangling_seqlevels) != 0L) {
