@@ -141,7 +141,7 @@ findRangesOverlaps <- function(query, subject)
                                              query.spaces, query.breaks,
                                              subject.starts, subject.widths,
                                              subject.spaces)
-        flip.query <- logical(length(encoding))
+        flip.query <- logical(length(C_ans$encoding))
     } else {
         if (!is(hits, "Hits"))
             stop("'hits' must be a Hits object")
@@ -159,7 +159,7 @@ findRangesOverlaps <- function(query, subject)
                                        subject.spaces,
                                        hits, flip.query)
     }
-    encoding <- factor(C_ans$encoding)
+    encoding <- as.factor(C_ans$encoding)
     new2("OverlapEncodings", Loffset=C_ans$Loffset, Roffset=C_ans$Roffset,
                              encoding=encoding, flippedQuery=flip.query,
                              check=FALSE)
@@ -272,7 +272,7 @@ flipQuery <- function(x, i)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Should we use a generic + methods for this?
+### Should we use generic + methods for this?
 ###
 
 .get_GRanges_spaces <- function(x)
@@ -358,124 +358,15 @@ selectEncodingWithCompatibleStrand <- function(ovencA, ovencB,
 }
 
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### isCompatibleWithSplicing().
-###
-
-.build_compatible_encoding_patterns <- function(njunc)
-{
-    ## Each "atom" must match exactly 1 code in the encoding.
-    ATOM0 <- "[fgij]"
-    if (njunc == 0L)
-        return(ATOM0)
-    #ntimes <- function(atom, n) rep.int(atom, n)
-    ntimes <- function(atom, n) {
-        if (n == 1L) atom else c(atom, "{", n, "}")
-    }
-    LEFT_ATOM <- "[jg]"
-    MIDDLE_ATOM <- "g"
-    RIGHT_ATOM <- "[gf]"
-    WILDCARD_ATOM <- "[^:-]"
-    sapply(seq_len(njunc + 1L),
-           function(i) {
-               if (i == 1L) {
-                   atoms <- c(LEFT_ATOM, ntimes(WILDCARD_ATOM, njunc))
-               } else if (i == njunc + 1L) {
-                   atoms <- c(ntimes(WILDCARD_ATOM, njunc), RIGHT_ATOM)
-               } else {
-                   atoms <- c(ntimes(WILDCARD_ATOM, i-1L),
-                              MIDDLE_ATOM,
-                              ntimes(WILDCARD_ATOM, njunc-i+1L))
-               }
-               paste0(atoms, collapse="")
-           })
-}
-
-setGeneric("isCompatibleWithSplicing",
-    function(x) standardGeneric("isCompatibleWithSplicing")
-)
-
-.build_CompatibleWithSplicing_pattern0 <- function(max.njunc1,
-                                                   max.Lnjunc, max.Rnjunc)
-{
-    ## Subpattern for single-end reads.
-    subpattern1 <- sapply(0:max.njunc1,
-                     function(njunc)
-                       paste0(.build_compatible_encoding_patterns(njunc),
-                              collapse=":"))
-    subpattern1 <- paste0(":(", paste0(subpattern1, collapse="|"), "):")
-
-    ## Subpattern for paired-end reads.
-    Lsubpattern <- sapply(0:max.Lnjunc,
-                     function(njunc)
-                       paste0(":",
-                              .build_compatible_encoding_patterns(njunc),
-                              "-",
-                              collapse="-[^:-]*"))
-    Lsubpattern <- paste0("(", paste0(Lsubpattern, collapse="|"), ")")
-
-    Rsubpattern <- sapply(0:max.Rnjunc,
-                     function(njunc)
-                       paste0("-",
-                              .build_compatible_encoding_patterns(njunc),
-                              ":",
-                              collapse="[^:-]*-"))
-    Rsubpattern <- paste0("(", paste0(Rsubpattern, collapse="|"), ")")
-
-    LRsubpattern <- paste0(Lsubpattern, ".*", Rsubpattern)
-
-    ## Final pattern.
-    paste0("(", subpattern1, "|", LRsubpattern, ")")
-}
-
-.build_CompatibleWithSplicing_pattern <- function(x)
-{
-    njunc <- njunc(x)
-    Lnjunc <- Lnjunc(x)
-    Rnjunc <- Rnjunc(x)
-    max.njunc1 <- max(c(0L, njunc[is.na(Lnjunc)]))
-    max.Lnjunc <- max(c(0L, Lnjunc), na.rm=TRUE)
-    max.Rnjunc <- max(c(0L, Rnjunc), na.rm=TRUE)
-    .build_CompatibleWithSplicing_pattern0(max.njunc1, max.Lnjunc, max.Rnjunc)
-}
-
-.isCompatibleWithSplicing <- function(x)
-{
-    if (!is.character(x))
-        stop("'x' must be a character vector")
-    pattern <- .build_CompatibleWithSplicing_pattern(x)
-    grepl(pattern, x)
-}
-
-.whichCompatibleWithSplicing <- function(x)
-{
-    if (!is.character(x))
-        stop("'x' must be a character vector")
-    pattern <- .build_CompatibleWithSplicing_pattern(x)
-    grep(pattern, x)
-}
-
-setMethod("isCompatibleWithSplicing", "character", .isCompatibleWithSplicing)
-
-setMethod("isCompatibleWithSplicing", "factor",
-    function(x)
-    {
-        if (length(x) == 0L)
-            return(logical(0))
-        idx <- .whichCompatibleWithSplicing(levels(x))
-        as.integer(x) %in% idx
-    }
-)
-
-setMethod("isCompatibleWithSplicing", "OverlapEncodings",
-    function(x) isCompatibleWithSplicing(encoding(x))
-)
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### isCompatibleWithSkippedExons().
 ###
 
+### FIXME: Revisit this and make sure it's doing the right thing for
+### paired-end encodings. Maybe look at isCompatibleWithSplicing() for some
+### inspiration (used to suffer from similar issue on paired-end encodings but
+### was refactored).
+
 setGeneric("isCompatibleWithSkippedExons", signature="x",
     function(x, max.skipped.exons=NA)
         standardGeneric("isCompatibleWithSkippedExons")
@@ -493,7 +384,7 @@ setGeneric("isCompatibleWithSkippedExons", signature="x",
                                    ":(...:)*", ":(....:)*")
     subpattern1 <- sapply(0:max.njunc1,
                      function(njunc)
-                       paste0(.build_compatible_encoding_patterns(njunc),
+                       paste0(build_compatible_encoding_subpatterns(njunc),
                               collapse=skipped_exons_subpatterns[njunc+1L]))
     subpattern1 <- paste0(":(", paste0(subpattern1, collapse="|"), "):")
 
@@ -501,7 +392,7 @@ setGeneric("isCompatibleWithSkippedExons", signature="x",
     Lsubpattern <- sapply(0:max.Lnjunc,
                      function(njunc)
                        paste0(":",
-                              .build_compatible_encoding_patterns(njunc),
+                              build_compatible_encoding_subpatterns(njunc),
                               "-",
                               collapse=".*"))
     Lsubpattern <- paste0("(", paste0(Lsubpattern, collapse="|"), ")")
@@ -509,7 +400,7 @@ setGeneric("isCompatibleWithSkippedExons", signature="x",
     Rsubpattern <- sapply(0:max.Rnjunc,
                      function(njunc)
                        paste0("-",
-                              .build_compatible_encoding_patterns(njunc),
+                              build_compatible_encoding_subpatterns(njunc),
                               ":",
                               collapse=".*"))
     Rsubpattern <- paste0("(", paste0(Rsubpattern, collapse="|"), ")")
@@ -539,18 +430,7 @@ setGeneric("isCompatibleWithSkippedExons", signature="x",
         stop("'x' must be a character vector")
     pattern1 <- .build_CompatibleWithSkippedExons_pattern(x,
                                                           max.skipped.exons)
-    pattern2 <- .build_CompatibleWithSplicing_pattern(x)
-    grepl(pattern1, x) & !grepl(pattern2, x)
-}
-
-.whichCompatibleWithSkippedExons <- function(x, max.skipped.exons=NA)
-{
-    if (!is.character(x))
-        stop("'x' must be a character vector")
-    pattern1 <- .build_CompatibleWithSkippedExons_pattern(x,
-                                                          max.skipped.exons)
-    pattern2 <- .build_CompatibleWithSplicing_pattern(x)
-    setdiff(grep(pattern1, x), grep(pattern2, x))
+    grepl(pattern1, x) & !isCompatibleWithSplicing(x)
 }
 
 setMethod("isCompatibleWithSkippedExons", "character",
@@ -560,11 +440,9 @@ setMethod("isCompatibleWithSkippedExons", "character",
 setMethod("isCompatibleWithSkippedExons", "factor",
     function(x, max.skipped.exons=NA)
     {
-        if (length(x) == 0L)
-            return(logical(0))
-        idx <- .whichCompatibleWithSkippedExons(levels(x),
-                        max.skipped.exons=max.skipped.exons)
-        as.integer(x) %in% idx
+        ok <- isCompatibleWithSkippedExons(levels(x),
+                                           max.skipped.exons=max.skipped.exons)
+        ok[as.integer(x)]
     }
 )
 
@@ -604,10 +482,10 @@ setMethod("isCompatibleWithSkippedExons", "OverlapEncodings",
 }
 
 ### 'encoding' must be a single encoding.
-### Returns a sorted integer vector, unnamed and strictly sorted if single-end
-### read, named and not necessarily strictly sorted if paired-end read (last
-### exon stepped by the left end can be the same as first exon stepped by right
-### end).
+### Returns an integer vector. If the encoding is single-end then the vector
+### is unnamed and strictly sorted. If it's paired-end then it's made of the
+### concatenation of the 2 strictly sorted integer vectors that correspond to
+### each end. In that case the vector is named.
 .extractSteppedExonRanks <- function(encoding, for.query.right.end=FALSE)
 {
     if (!isTRUEorFALSE(for.query.right.end))
@@ -620,7 +498,7 @@ setMethod("isCompatibleWithSkippedExons", "OverlapEncodings",
         if (for.query.right.end)
             stop("cannot use 'for.query.right.end=TRUE' ",
                  "on single-end encoding: ", encoding)
-        encoding_patterns <- .build_compatible_encoding_patterns(njunc)
+        encoding_patterns <- build_compatible_encoding_subpatterns(njunc)
         return(.extractSteppedExonRanksFromEncodingBlocks(encoding_blocks,
                                                           encoding_patterns))
     }
@@ -631,18 +509,12 @@ setMethod("isCompatibleWithSkippedExons", "OverlapEncodings",
     if (!all(elementNROWS(encoding_blocks) == 2L))  # should never happen
         stop(encoding, ": invalid encoding")
     encoding_blocks <- matrix(unlist(encoding_blocks, use.names=FALSE), nrow=2L)
-    Lencoding_patterns <- .build_compatible_encoding_patterns(njunc[1L])
+    Lencoding_patterns <- build_compatible_encoding_subpatterns(njunc[1L])
     Lranks <- .extractSteppedExonRanksFromEncodingBlocks(encoding_blocks[1L, ],
                                                          Lencoding_patterns)
-    Rencoding_patterns <- .build_compatible_encoding_patterns(njunc[2L])
+    Rencoding_patterns <- build_compatible_encoding_subpatterns(njunc[2L])
     Rranks <- .extractSteppedExonRanksFromEncodingBlocks(encoding_blocks[2L, ],
                                                          Rencoding_patterns)
-    if (length(Lranks) == 0L || length(Rranks) == 0L ||
-        Lranks[length(Lranks)] > Rranks[1L]) {
-        ranks <- integer(0)
-        names(ranks) <- character(0)
-        return(ranks)
-    }
     if (for.query.right.end)
         return(Rranks)  # unnamed! (like for a single-end read)
     names(Rranks) <- rep.int("R", length(Rranks))
@@ -870,16 +742,14 @@ extractQueryStartInTranscript <- function(query, subject,
             stop("'ovenc' must be an OverlapEncodings object")
         if (length(ovenc) != length(query))
             stop("when not NULL, 'ovenc' must have the same length ",
-                 "as 'hits', if specified, otherwiseaas 'query'")
+                 "as 'hits', if specified, otherwise as 'query'")
     }
     if (!isTRUEorFALSE(for.query.right.end))
         stop("'for.query.right.end' must be TRUE or FALSE")
 
     query <- flipQuery(query, flippedQuery(ovenc))
 
-    ## Extract start/end/strand of the first range
-    ## in each top-level element of 'query'.
-    qii1 <- start(query@partitioning)
+    ## Extract first range from each list element of 'query'.
     if (for.query.right.end) {
         query.break <- mcols(query)$query.break
         if (is.null(query.break))
@@ -888,11 +758,16 @@ extractQueryStartInTranscript <- function(query, subject,
                  "indicating for each paired-end read the position of the ",
                  "break between the ranges coming from one end and those ",
                  "coming from the other end")
-        qii1 <- qii1 + query.break
+        query <- ptail(query, n=-query.break)
     }
-    query_start1 <- start(query@unlistData)[qii1]
-    query_end1 <- end(query@unlistData)[qii1]
-    query_strand1 <- as.factor(strand(query@unlistData))[qii1]
+    query1 <- unlist(phead(query, n=1L), use.names=FALSE)
+    ## A sanity check.
+    if (length(query1) != length(query)) 
+        stop("some list elements in 'query' are empty")
+
+    query_start1 <- start(query1)
+    query_end1 <- end(query1)
+    query_strand1 <- as.factor(strand(query1))
 
     ## Extract start/end/strand of the first spanned exon
     ## in each top-level element of 'subject'.
