@@ -5,12 +5,11 @@
 
 
 setGeneric("findCompatibleOverlaps",
-    function(query, subject, algorithm=c("nclist", "intervaltree"))
-        standardGeneric("findCompatibleOverlaps")
+    function(query, subject) standardGeneric("findCompatibleOverlaps")
 )
 
 .GAlignmentsORGAlignmentPairs.findCompatibleOverlaps <-
-    function(query, subject, algorithm=c("nclist", "intervaltree"))
+    function(query, subject)
 {
     ## Starting with BioC 3.2, the 'order.as.in.query' argument is not
     ## supported anymore for GAlignmentPairs objects.
@@ -20,8 +19,7 @@ setGeneric("findCompatibleOverlaps",
         grl <- grglist(query, order.as.in.query=TRUE)
     ## TODO: Use 'type="within"' when it's supported for circular
     ## sequences like the mitochondrial chromosome.
-    ov <- findOverlaps(grl, subject, algorithm=match.arg(algorithm),
-                       ignore.strand=TRUE)
+    ov <- findOverlaps(grl, subject, ignore.strand=TRUE)
     ovenc <- encodeOverlaps(grl, subject, hits=ov,
                             flip.query.if.wrong.strand=TRUE)
     ov_is_compat <- isCompatibleWithSplicing(ovenc)
@@ -36,11 +34,9 @@ setMethod("findCompatibleOverlaps", c("GAlignmentPairs", "GRangesList"),
     .GAlignmentsORGAlignmentPairs.findCompatibleOverlaps
 )
 
-countCompatibleOverlaps <- function(query, subject,
-                                    algorithm=c("nclist", "intervaltree"))
+countCompatibleOverlaps <- function(query, subject)
 {
-    compatov <- findCompatibleOverlaps(query, subject,
-                                       algorithm=match.arg(algorithm))
+    compatov <- findCompatibleOverlaps(query, subject)
     tabulate(queryHits(compatov), nbins=queryLength(compatov))
 }
 
