@@ -28,7 +28,7 @@
     if (is(param, "RangesList")) {
         ## We support RangesList just because ScanBamParam() supports it too
         ## and also because that's what's returned by bamWhich().
-        param <- param[elementLengths(param) != 0L]
+        param <- param[elementNROWS(param) != 0L]
         if (length(unlist(param, use.names=FALSE)) != 1L)
             stop("when a RangesList object, 'param' must contain exactly 1 ",
                  "genomic region\n  (i.e. 'unlist(param)' must have length 1)")
@@ -41,7 +41,7 @@
              "of length 1, or a character\n  string specifying a single ",
              "genomic region (in the \"chr14:5201-5300\" format)")
     param_which <- bamWhich(param)
-    param_which <- param_which[elementLengths(param_which) != 0L]
+    param_which <- param_which[elementNROWS(param_which) != 0L]
     if (length(unlist(param_which, use.names=FALSE)) != 1L)
         stop("when a ScanBamParam object, 'param' must contain exactly 1 ",
              "genomic region\n  (i.e. 'unlist(bamWhich(param))' must have ",
