@@ -73,7 +73,7 @@ U1.GAL_dup2unq <- match(U1.GAL_qnames, U1.GAL_qnames)
 
 
 ###################################################
-### code chunk number 8: gaps-in-U1.GAL
+### code chunk number 8: skipped-regions-in-U1.GAL
 ###################################################
 head(unique(cigar(U1.GAL)))
 table(njunc(U1.GAL))
@@ -132,7 +132,7 @@ U3.GALP_dup2unq <- match(U3.GALP_qnames, U3.GALP_qnames)
 
 
 ###################################################
-### code chunk number 17: gaps-in-U3.GALP
+### code chunk number 17: skipped-region-in-U3.GALP
 ###################################################
 head(unique(cigar(first(U3.GALP))))
 head(unique(cigar(last(U3.GALP))))
@@ -369,7 +369,7 @@ sort(U1.ovenc_table[isCompatibleWithSplicing(U1.unique_encodings)])
 ### code chunk number 47: U1.OV00_is_comp
 ###################################################
 U1.OV00_is_comp <- isCompatibleWithSplicing(U1.ovenc)
-table(U1.OV00_is_comp)  # 531797 "compatible" overlaps
+table(U1.OV00_is_comp)  # 531797 "splice compatible" overlaps
 
 
 ###################################################
@@ -436,7 +436,7 @@ sort(U3.ovenc_table[isCompatibleWithSplicing(U3.unique_encodings)])
 ### code chunk number 56: U3.OV00_is_comp
 ###################################################
 U3.OV00_is_comp <- isCompatibleWithSplicing(U3.ovenc)
-table(U3.OV00_is_comp)  # 106835 "compatible" paired-end overlaps
+table(U3.OV00_is_comp)  # 106835 "splice compatible" paired-end overlaps
 
 
 ###################################################
@@ -762,7 +762,7 @@ sort(U1.ovenc_table[isCompatibleWithSkippedExons(U1.unique_encodings)])
 ### code chunk number 88: U1.OV00_is_acomp
 ###################################################
 U1.OV00_is_acomp <- isCompatibleWithSkippedExons(U1.ovenc)
-table(U1.OV00_is_acomp)  # 1202 "almost compatible" overlaps
+table(U1.OV00_is_acomp)  # 1202 "almost splice compatible" overlaps
 
 
 ###################################################
@@ -806,7 +806,7 @@ sort(U3.ovenc_table[isCompatibleWithSkippedExons(U3.unique_encodings)])
 ### code chunk number 94: U3.OV00_is_acomp
 ###################################################
 U3.OV00_is_acomp <- isCompatibleWithSkippedExons(U3.ovenc)
-table(U3.OV00_is_acomp)  # 141 "almost compatible" paired-end overlaps
+table(U3.OV00_is_acomp)  # 141 "almost splice compatible" paired-end overlaps
 
 
 ###################################################
